pub struct PropagatedTokenValidationConfig {
pub required_issuers: Vec<String>,
pub allowed_audiences: Vec<String>,
pub required_scopes: Vec<String>,
pub allowed_azp: Vec<String>,
}Expand description
Additional token constraints evaluated before a bearer token may be forwarded.
Fields
required_issuers: Vec<String>Allowed issuers for the upstream token source.
allowed_audiences: Vec<String>At least one audience must match when this list is not empty.
required_scopes: Vec<String>Every listed scope must be present when this list is not empty.
allowed_azp: Vec<String>Allowed authorized-party values when this list is not empty.
Implementations
Sourceimpl PropagatedTokenValidationConfig
impl PropagatedTokenValidationConfig
Sourcepub fn builder() -> PropagatedTokenValidationConfigBuilder<((), (), (), ())>
pub fn builder() -> PropagatedTokenValidationConfigBuilder<((), (), (), ())>
Create a builder for building PropagatedTokenValidationConfig.
On the builder, call .required_issuers(...)(optional), .allowed_audiences(...)(optional), .required_scopes(...)(optional), .allowed_azp(...)(optional) to set the values of the fields.
Finally, call .build() to create the instance of PropagatedTokenValidationConfig.